#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/socket.h>
#include <arpa/inet.h>
#include <string.h>
#include <netdb.h>
#include "mdns.h"
#include "mdnsd.h"

void
background()
{
	int fd;

	switch ((int)fork())
	{
	    case -1:
		perror("fork");
		exit(1);
	    case 0:
		break;
	    default:
		exit(0);
	}

#ifdef TIOCNOTTY
	if (ioctl(fileno(stdin), TIOCNOTTY) == -1)
		perror("detach_console");
#endif
	freopen("/dev/null", "r", stdin);

	fd = open("/dev/null", O_WRONLY, 0666);
	dup2(fd, fileno(stdout));
	dup2(fd, fileno(stderr));
	close(fd);

	setsid();
}

int
main(int argc, char **argv)
{
	char hostname[0x100], ifname[0x100];
	struct hostent *hp;
	struct in_addr saddr;

        if (gethostname(hostname, sizeof(hostname) - 1) == -1)
        {
                printf("Couldn't retrieve humax hostname.\n");
		return 1;
        }

	if (!(hp = gethostbyname(hostname)))
	{
		printf("Couldn't retrieve humax IP address.\n");
		return 1;
	}
	memmove((char *)&saddr.s_addr, (char *)hp->h_addr,
	    sizeof(saddr.s_addr));
	printf("Hostname: %s (%s)\n", hostname, inet_ntoa(saddr));

	struct mdnsd *svr = mdnsd_start();
	if (svr == NULL) {
		printf("mdnsd_start() error\n");
		return 1;
	}
	printf("Started MDNS Service\n");

	mdnsd_set_hostname(svr, hostname, saddr.s_addr);

	sprintf(ifname, "Humax Fox T2 (%s) Web Interface", hostname);

	const char *txt[] = {
		"path=/", 
		NULL
	};
	struct mdns_service *svc = mdnsd_register_svc(
	    svr, ifname, "_http._tcp.local", 80,
	    NULL, txt);
	//mdns_service_destroy(svc);

	printf("Registered name.\n");

	for (;;)
		sleep(3600);

	// mdnsd_stop(svr);

	return 0;
}

